@@ -1,3 +1,3 @@
 pub use crate::error::DecodeError;
-pub use crate::opcode::{Instruction, Opcode, Python27};
+pub use crate::opcode::{Instruction, Opcode};
 pub use crate::{decode, decode_py27};
